@@ -11,9 +11,15 @@ def main():
     ]
     
     model_ = Model(components, beam_z = 1.0, beam_type = 'point', num_rays = 32, beam_semi_angle = 0.03)
-    run_pyqt(model_)
+    
+    viewer = run_pyqt(model_)  
+    
+    viewer.show()
+    
+    return viewer 
 
 if __name__ == '__main__':
+    
     AppWindow = QApplication(sys.argv)
-    main()
-    sys.exit(AppWindow.exec_())
+    viewer = main()    
+    AppWindow.exec_()
